#!/bin/sh

#############################################################################
#  Licensed Materials - Property of IBM
#  5724-M24
#  Copyright IBM Corporation 2009. All Rights Reserved.
#  US Government Users Restricted Rights - Use, duplication or disclosure
#  restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################

echo ""
echo "Start Business Space Schema Upgrading Script"
echo ""

#######################################################
#                                                     #
# Subroutine: Usage                                   #
#                                                     #
#######################################################
usage () {
  echo  ""
  echo  "upgradeBSpaceSchema -profileName <profile name> -nodeName <node name>"
  echo 	"                  -serverName <server name> -clusterName  <cluster name> -wasHome(optional) <WAS home>"
  echo  ""
  echo  "where: " 
  echo  ""
  echo  "-profileName <profile name>:"
  echo  "    The name of profile you intend to upgrade"
  echo  ""
  echo  "-nodeName <node name>:"
  echo  "    The name of node"
  echo  ""
  echo  "-serverName <server name>:"
  echo  "    The name of server"
  echo  ""
  echo  "-clusterName <cluster name>:"
  echo  "    The name of cluster"
  echo  ""
  echo  "-wasHome <WAS home directory>:"
  echo  "    The location of the profile's WAS home directory"
  exit
 }   
  

######################################################
#                                                     #
# Read command line options                           #
#                                                     #
#######################################################

if [ $# -ne 8 ]; then
  if [ $# -ne 6 ]; then
    if [ $# -ne 4 ]; then
      usage
    fi
  fi  
fi
  
while [ $# -gt 0 ]; do
  case $1 in
    -wasHome) WASHOME=$2; shift; shift;;
    -profileName) profileName=$2; shift; shift;;
	  -nodeName) nodeName=$2; shift; shift;;
	  -serverName) serverName=$2; shift; shift;;
	  -clusterName) clusterName=$2; shift; shift;;
    -h) usage;;
    -help) usage;;
    *) echo "Invalid parameter: $1"; usage;;
  esac;
done

#######################################################
#                                                     #
# Set WAS environment                                 #
#                                                     #
#######################################################
CUR_DIR=$(cd "$(dirname "$0")"; pwd)
cd "$CUR_DIR/../../"

if [ -z "$WASHOME" ] ; then
  WASHOME=`pwd`
fi

cd "$WASHOME"/bin

if [ -f setupCmdLine.sh ];then
	./setupCmdLine.sh
else
	echo "Please enter WAS Home directory: "
    read WASHOME
	. "$WASHOME/bin/setupCmdLine.sh"
fi


#######################################################
#                                                     #
# call upgradeBSpaceSchema.py                         #
#                                                     #
#######################################################
if [ -z "$clusterName" ] ; then
  "$WASHOME/bin/wsadmin.sh" -connType NONE -profileName $profileName -f "$CUR_DIR/upgradeBSpaceSchema.py" "$WASHOME" $nodeName $serverName
fi

if [ -z "$serverName" ] ; then
  "$WASHOME/bin/wsadmin.sh" -connType NONE -profileName $profileName -f "$CUR_DIR/upgradeBSpaceSchema.py" "$WASHOME" $clusterName
fi

cd $CUR_DIR

REPLACE_WAS_HOME=$WASHOME

# ./upgradeBSpaceSchemaTables.sh
. ./upgradeBSpaceSchemaTables.sh

echo "Business Space Schema Upgrading was completed."
